@@ -19,18 +19,25 @@ import json
 import logging
 import threading
 import traceback
+from os import environ
 from time import time_ns
-from typing import Any, Callable, Optional, Tuple, Union
+from typing import Any, Callable, Optional, Tuple, Union  # noqa
 
 from opentelemetry._logs import Logger as APILogger
 from opentelemetry._logs import LoggerProvider as APILoggerProvider
 from opentelemetry._logs import LogRecord as APILogRecord
 from opentelemetry._logs import (
+    NoOpLogger,
     SeverityNumber,
     get_logger,
     get_logger_provider,
     std_to_otel,
 )
+from opentelemetry.attributes import BoundedAttributes
+from opentelemetry.sdk.environment_variables import (
+    OTEL_ATTRIBUTE_COUNT_LIMIT,
+    OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT,
+)
 from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk.util import ns_to_iso_str
 from opentelemetry.sdk.util.instrumentation import InstrumentationScope
@@ -45,6 +52,101 @@ from opentelemetry.util.types import Attributes
 
 _logger = logging.getLogger(__name__)
 
+_DEFAULT_OTEL_ATTRIBUTE_COUNT_LIMIT = 128
+_ENV_VALUE_UNSET = ""
+
+
+class LogLimits:
+    """This class is based on a SpanLimits class in the Tracing module.
+
+    This class represents the limits that should be enforced on recorded data such as events, links, attributes etc.
+
+    This class does not enforce any limits itself. It only provides a way to read limits from env,
+    default values and from user provided arguments.
+
+    All limit arguments must be either a non-negative integer, ``None`` or ``LogLimits.UNSET``.
+
+    - All limit arguments are optional.
+    - If a limit argument is not set, the class will try to read its value from the corresponding
+      environment variable.
+    - If the environment variable is not set, the default value, if any, will be used.
+
+    Limit precedence:
+
+    - If a model specific limit is set, it will be used.
+    - Else if the corresponding global limit is set, it will be used.
+    - Else if the model specific limit has a default value, the default value will be used.
+    - Else if the global limit has a default value, the default value will be used.
+
+    Args:
+        max_attributes: Maximum number of attributes that can be added to a span, event, and link.
+            Environment variable: ``OTEL_ATTRIBUTE_COUNT_LIMIT``
+            Default: {_DEFAULT_OTEL_ATTRIBUTE_COUNT_LIMIT}
+        max_attribute_length: Maximum length an attribute value can have. Values longer than
+            the specified length will be truncated.
+    """
+
+    UNSET = -1
+
+    def __init__(
+        self,
+        max_attributes: Optional[int] = None,
+        max_attribute_length: Optional[int] = None,
+    ):
+
+        # attribute count
+        global_max_attributes = self._from_env_if_absent(
+            max_attributes, OTEL_ATTRIBUTE_COUNT_LIMIT
+        )
+        self.max_attributes = (
+            global_max_attributes
+            if global_max_attributes is not None
+            else _DEFAULT_OTEL_ATTRIBUTE_COUNT_LIMIT
+        )
+
+        # attribute length
+        self.max_attribute_length = self._from_env_if_absent(
+            max_attribute_length,
+            OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT,
+        )
+
+    def __repr__(self):
+        return f"{type(self).__name__}(max_attributes={self.max_attributes}, max_attribute_length={self.max_attribute_length})"
+
+    @classmethod
+    def _from_env_if_absent(
+        cls, value: Optional[int], env_var: str, default: Optional[int] = None
+    ) -> Optional[int]:
+        if value == cls.UNSET:
+            return None
+
+        err_msg = "{0} must be a non-negative integer but got {}"
+
+        # if no value is provided for the limit, try to load it from env
+        if value is None:
+            # return default value if env var is not set
+            if env_var not in environ:
+                return default
+
+            str_value = environ.get(env_var, "").strip().lower()
+            if str_value == _ENV_VALUE_UNSET:
+                return None
+
+            try:
+                value = int(str_value)
+            except ValueError:
+                raise ValueError(err_msg.format(env_var, str_value))
+
+        if value < 0:
+            raise ValueError(err_msg.format(env_var, value))
+        return value
+
+
+_UnsetLogLimits = LogLimits(
+    max_attributes=LogLimits.UNSET,
+    max_attribute_length=LogLimits.UNSET,
+)
+
 
 class LogRecord(APILogRecord):
     """A LogRecord instance represents an event being logged.
@@ -66,6 +168,7 @@ class LogRecord(APILogRecord):
         body: Optional[Any] = None,
         resource: Optional[Resource] = None,
         attributes: Optional[Attributes] = None,
+        limits: Optional[LogLimits] = _UnsetLogLimits,
     ):
         super().__init__(
             **{
@@ -77,7 +180,12 @@ class LogRecord(APILogRecord):
                 "severity_text": severity_text,
                 "severity_number": severity_number,
                 "body": body,
-                "attributes": attributes,
+                "attributes": BoundedAttributes(
+                    maxlen=limits.max_attributes,
+                    attributes=attributes if bool(attributes) else None,
+                    immutable=False,
+                    max_value_len=limits.max_attribute_length,
+                ),
             }
         )
         self.resource = resource
@@ -93,8 +201,12 @@ class LogRecord(APILogRecord):
                 "body": self.body,
                 "severity_number": repr(self.severity_number),
                 "severity_text": self.severity_text,
-                "attributes": self.attributes,
+                "attributes": dict(self.attributes)
+                if bool(self.attributes)
+                else None,
+                "dropped_attributes": self.dropped_attributes,
                 "timestamp": ns_to_iso_str(self.timestamp),
+                "observed_timestamp": ns_to_iso_str(self.observed_timestamp),
                 "trace_id": f"0x{format_trace_id(self.trace_id)}"
                 if self.trace_id is not None
                 else "",
@@ -109,6 +221,12 @@ class LogRecord(APILogRecord):
             indent=indent,
         )
 
+    @property
+    def dropped_attributes(self) -> int:
+        if self.attributes:
+            return self.attributes.dropped
+        return 0
+
 
 class LogData:
     """Readable LogRecord data plus associated InstrumentationLibrary."""
@@ -296,7 +414,7 @@ _RESERVED_ATTRS = frozenset(
         "exc_text",
         "filename",
         "funcName",
-        "getMessage",
+        "message",
         "levelname",
         "levelno",
         "lineno",
@@ -311,6 +429,7 @@ _RESERVED_ATTRS = frozenset(
         "stack_info",
         "thread",
         "threadName",
+        "taskName",
     )
 )
 
@@ -337,55 +456,107 @@ class LoggingHandler(logging.Handler):
         attributes = {
             k: v for k, v in vars(record).items() if k not in _RESERVED_ATTRS
         }
+
+        # Add standard code attributes for logs.
+        attributes[SpanAttributes.CODE_FILEPATH] = record.pathname
+        attributes[SpanAttributes.CODE_FUNCTION] = record.funcName
+        attributes[SpanAttributes.CODE_LINENO] = record.lineno
+
         if record.exc_info:
-            exc_type = ""
-            message = ""
-            stack_trace = ""
             exctype, value, tb = record.exc_info
             if exctype is not None:
-                exc_type = exctype.__name__
+                attributes[SpanAttributes.EXCEPTION_TYPE] = exctype.__name__
             if value is not None and value.args:
-                message = value.args[0]
+                attributes[SpanAttributes.EXCEPTION_MESSAGE] = value.args[0]
             if tb is not None:
                 # https://github.com/open-telemetry/opentelemetry-specification/blob/9fa7c656b26647b27e485a6af7e38dc716eba98a/specification/trace/semantic_conventions/exceptions.md#stacktrace-representation
-                stack_trace = "".join(
+                attributes[SpanAttributes.EXCEPTION_STACKTRACE] = "".join(
                     traceback.format_exception(*record.exc_info)
                 )
-            attributes[SpanAttributes.EXCEPTION_TYPE] = exc_type
-            attributes[SpanAttributes.EXCEPTION_MESSAGE] = message
-            attributes[SpanAttributes.EXCEPTION_STACKTRACE] = stack_trace
         return attributes
 
     def _translate(self, record: logging.LogRecord) -> LogRecord:
         timestamp = int(record.created * 1e9)
+        observered_timestamp = time_ns()
         span_context = get_current_span().get_span_context()
         attributes = self._get_attributes(record)
+        # This comment is taken from GanyedeNil's PR #3343, I have redacted it
+        # slightly for clarity:
+        # According to the definition of the Body field type in the
+        # OTel 1.22.0 Logs Data Model article, the Body field should be of
+        # type 'any' and should not use the str method to directly translate
+        # the msg. This is because str only converts non-text types into a
+        # human-readable form, rather than a standard format, which leads to
+        # the need for additional operations when collected through a log
+        # collector.
+        # Considering that he Body field should be of type 'any' and should not
+        # use the str method but record.msg is also a string type, then the
+        # difference is just the self.args formatting?
+        # The primary consideration depends on the ultimate purpose of the log.
+        # Converting the default log directly into a string is acceptable as it
+        # will be required to be presented in a more readable format. However,
+        # this approach might not be as "standard" when hoping to aggregate
+        # logs and perform subsequent data analysis. In the context of log
+        # extraction, it would be more appropriate for the msg to be
+        # converted into JSON format or remain unchanged, as it will eventually
+        # be transformed into JSON. If the final output JSON data contains a
+        # structure that appears similar to JSON but is not, it may confuse
+        # users. This is particularly true for operation and maintenance
+        # personnel who need to deal with log data in various languages.
+        # Where is the JSON converting occur? and what about when the msg
+        # represents something else but JSON, the expected behavior change?
+        # For the ConsoleLogExporter, it performs the to_json operation in
+        # opentelemetry.sdk._logs._internal.export.ConsoleLogExporter.__init__,
+        # so it can handle any type of input without problems. As for the
+        # OTLPLogExporter, it also handles any type of input encoding in
+        # _encode_log located in
+        # opentelemetry.exporter.otlp.proto.common._internal._log_encoder.
+        # Therefore, no extra operation is needed to support this change.
+        # The only thing to consider is the users who have already been using
+        # this SDK. If they upgrade the SDK after this change, they will need
+        # to readjust their logging collection rules to adapt to the latest
+        # output format. Therefore, this change is considered a breaking
+        # change and needs to be upgraded at an appropriate time.
         severity_number = std_to_otel(record.levelno)
+        if isinstance(record.msg, str) and record.args:
+            body = record.msg % record.args
+        else:
+            body = record.msg
+
+        # related to https://github.com/open-telemetry/opentelemetry-python/issues/3548
+        # Severity Text = WARN as defined in https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/logs/data-model.md#displaying-severity.
+        level_name = (
+            "WARN" if record.levelname == "WARNING" else record.levelname
+        )
+
         return LogRecord(
             timestamp=timestamp,
+            observed_timestamp=observered_timestamp,
             trace_id=span_context.trace_id,
             span_id=span_context.span_id,
             trace_flags=span_context.trace_flags,
-            severity_text=record.levelname,
+            severity_text=level_name,
             severity_number=severity_number,
-            body=record.getMessage(),
+            body=body,
             resource=self._logger.resource,
             attributes=attributes,
         )
 
     def emit(self, record: logging.LogRecord) -> None:
         """
-        Emit a record.
+        Emit a record. Skip emitting if logger is NoOp.
 
         The record is translated to OTel format, and then sent across the pipeline.
         """
-        self._logger.emit(self._translate(record))
+        if not isinstance(self._logger, NoOpLogger):
+            self._logger.emit(self._translate(record))
 
     def flush(self) -> None:
         """
-        Flushes the logging output.
+        Flushes the logging output. Skip flushing if logger is NoOp.
         """
-        self._logger_provider.force_flush()
+        if not isinstance(self._logger, NoOpLogger):
+            self._logger_provider.force_flush()
 
 
 class Logger(APILogger):
@@ -422,14 +593,17 @@ class Logger(APILogger):
 class LoggerProvider(APILoggerProvider):
     def __init__(
         self,
-        resource: Resource = Resource.create(),
+        resource: Resource = None,
         shutdown_on_exit: bool = True,
         multi_log_record_processor: Union[
             SynchronousMultiLogRecordProcessor,
             ConcurrentMultiLogRecordProcessor,
         ] = None,
     ):
-        self._resource = resource
+        if resource is None:
+            self._resource = Resource.create({})
+        else:
+            self._resource = resource
         self._multi_log_record_processor = (
             multi_log_record_processor or SynchronousMultiLogRecordProcessor()
         )
