@@ -13,10 +13,10 @@
 # limitations under the License.
 
 from itertools import permutations
+from logging import WARNING
 from math import ldexp
 from sys import float_info
 from types import MethodType
-from unittest import TestCase
 from unittest.mock import Mock, patch
 
 from opentelemetry.sdk.metrics._internal.aggregation import (
@@ -37,6 +37,10 @@ from opentelemetry.sdk.metrics._internal.exponential_histogram.mapping.logarithm
     LogarithmMapping,
 )
 from opentelemetry.sdk.metrics._internal.measurement import Measurement
+from opentelemetry.sdk.metrics.view import (
+    ExponentialBucketHistogramAggregation,
+)
+from opentelemetry.test import TestCase
 
 
 def get_counts(buckets: Buckets) -> int:
@@ -77,6 +81,39 @@ def swap(
 
 
 class TestExponentialBucketHistogramAggregation(TestCase):
+    @patch("opentelemetry.sdk.metrics._internal.aggregation.LogarithmMapping")
+    def test_create_aggregation(self, mock_logarithm_mapping):
+        exponential_bucket_histogram_aggregation = (
+            ExponentialBucketHistogramAggregation()
+        )._create_aggregation(Mock(), Mock(), Mock())
+
+        self.assertEqual(
+            exponential_bucket_histogram_aggregation._max_scale, 20
+        )
+
+        mock_logarithm_mapping.assert_called_with(20)
+
+        exponential_bucket_histogram_aggregation = (
+            ExponentialBucketHistogramAggregation(max_scale=10)
+        )._create_aggregation(Mock(), Mock(), Mock())
+
+        self.assertEqual(
+            exponential_bucket_histogram_aggregation._max_scale, 10
+        )
+
+        mock_logarithm_mapping.assert_called_with(10)
+
+        with self.assertLogs(level=WARNING):
+            exponential_bucket_histogram_aggregation = (
+                ExponentialBucketHistogramAggregation(max_scale=100)
+            )._create_aggregation(Mock(), Mock(), Mock())
+
+        self.assertEqual(
+            exponential_bucket_histogram_aggregation._max_scale, 100
+        )
+
+        mock_logarithm_mapping.assert_called_with(100)
+
     def assertInEpsilon(self, first, second, epsilon):
         self.assertLessEqual(first, (second * (1 + epsilon)))
         self.assertGreaterEqual(first, (second * (1 - epsilon)))
@@ -756,11 +793,8 @@ class TestExponentialBucketHistogramAggregation(TestCase):
 
                 index = mapping.map_to_index(value)
 
-                try:
+                with self.assertNotRaises(Exception):
                     boundary = mapping.get_lower_boundary(index + 1)
-                except Exception as error:
-                    raise error
-                    self.fail(f"Unexpected exception {error} raised")
 
                 if boundary < value:
                     above += 1
@@ -799,30 +833,6 @@ class TestExponentialBucketHistogramAggregation(TestCase):
         """
         Tests a repeated cycle of aggregation and collection.
         """
-        """
-        try:
-            exponential_histogram_aggregation = (
-                _ExponentialBucketHistogramAggregation(
-                    Mock(),
-                    Mock(),
-                )
-            )
-
-            exponential_histogram_aggregation.aggregate(Measurement(2, Mock()))
-            exponential_histogram_aggregation.collect(
-                AggregationTemporality.CUMULATIVE, 0
-            )
-            exponential_histogram_aggregation.aggregate(Measurement(2, Mock()))
-            exponential_histogram_aggregation.collect(
-                AggregationTemporality.CUMULATIVE, 0
-            )
-            exponential_histogram_aggregation.aggregate(Measurement(2, Mock()))
-            exponential_histogram_aggregation.collect(
-                AggregationTemporality.CUMULATIVE, 0
-            )
-        except Exception as error:
-            self.fail(f"Unexpected exception raised: {error}")
-        """
         exponential_histogram_aggregation = (
             _ExponentialBucketHistogramAggregation(
                 Mock(),
