@@ -25,6 +25,7 @@ from opentelemetry.sdk.metrics._internal.aggregation import (
 )
 from opentelemetry.sdk.metrics._internal.instrument import (
     _Counter,
+    _Gauge,
     _Histogram,
     _ObservableCounter,
     _ObservableGauge,
@@ -65,7 +66,7 @@ class TestSynchronousSumAggregation(TestCase):
         synchronous_sum_aggregation.aggregate(measurement(2))
         synchronous_sum_aggregation.aggregate(measurement(3))
 
-        self.assertEqual(synchronous_sum_aggregation._value, 6)
+        self.assertEqual(synchronous_sum_aggregation._current_value, 6)
 
         synchronous_sum_aggregation = _SumAggregation(
             Mock(), True, AggregationTemporality.DELTA, 0
@@ -75,7 +76,7 @@ class TestSynchronousSumAggregation(TestCase):
         synchronous_sum_aggregation.aggregate(measurement(-2))
         synchronous_sum_aggregation.aggregate(measurement(3))
 
-        self.assertEqual(synchronous_sum_aggregation._value, 2)
+        self.assertEqual(synchronous_sum_aggregation._current_value, 2)
 
     def test_aggregate_cumulative(self):
         """
@@ -90,7 +91,7 @@ class TestSynchronousSumAggregation(TestCase):
         synchronous_sum_aggregation.aggregate(measurement(2))
         synchronous_sum_aggregation.aggregate(measurement(3))
 
-        self.assertEqual(synchronous_sum_aggregation._value, 6)
+        self.assertEqual(synchronous_sum_aggregation._current_value, 6)
 
         synchronous_sum_aggregation = _SumAggregation(
             Mock(), True, AggregationTemporality.CUMULATIVE, 0
@@ -100,7 +101,7 @@ class TestSynchronousSumAggregation(TestCase):
         synchronous_sum_aggregation.aggregate(measurement(-2))
         synchronous_sum_aggregation.aggregate(measurement(3))
 
-        self.assertEqual(synchronous_sum_aggregation._value, 2)
+        self.assertEqual(synchronous_sum_aggregation._current_value, 2)
 
     def test_collect_delta(self):
         """
@@ -269,7 +270,10 @@ class TestExplicitBucketHistogramAggregation(TestCase):
 
         explicit_bucket_histogram_aggregation = (
             _ExplicitBucketHistogramAggregation(
-                Mock(), 0, boundaries=[0, 2, 4]
+                Mock(),
+                AggregationTemporality.DELTA,
+                0,
+                boundaries=[0, 2, 4],
             )
         )
 
@@ -283,22 +287,22 @@ class TestExplicitBucketHistogramAggregation(TestCase):
 
         # The first bucket keeps count of values between (-inf, 0] (-1 and 0)
         self.assertEqual(
-            explicit_bucket_histogram_aggregation._bucket_counts[0], 2
+            explicit_bucket_histogram_aggregation._current_value[0], 2
         )
 
         # The second bucket keeps count of values between (0, 2] (1 and 2)
         self.assertEqual(
-            explicit_bucket_histogram_aggregation._bucket_counts[1], 2
+            explicit_bucket_histogram_aggregation._current_value[1], 2
         )
 
         # The third bucket keeps count of values between (2, 4] (3 and 4)
         self.assertEqual(
-            explicit_bucket_histogram_aggregation._bucket_counts[2], 2
+            explicit_bucket_histogram_aggregation._current_value[2], 2
         )
 
         # The fourth bucket keeps count of values between (4, inf) (3 and 4)
         self.assertEqual(
-            explicit_bucket_histogram_aggregation._bucket_counts[3], 1
+            explicit_bucket_histogram_aggregation._current_value[3], 1
         )
 
         histo = explicit_bucket_histogram_aggregation.collect(
@@ -313,7 +317,9 @@ class TestExplicitBucketHistogramAggregation(TestCase):
         """
 
         explicit_bucket_histogram_aggregation = (
-            _ExplicitBucketHistogramAggregation(Mock(), 0)
+            _ExplicitBucketHistogramAggregation(
+                Mock(), AggregationTemporality.CUMULATIVE, 0
+            )
         )
 
         explicit_bucket_histogram_aggregation.aggregate(measurement(-1))
@@ -327,7 +333,10 @@ class TestExplicitBucketHistogramAggregation(TestCase):
 
         explicit_bucket_histogram_aggregation = (
             _ExplicitBucketHistogramAggregation(
-                Mock(), 0, record_min_max=False
+                Mock(),
+                AggregationTemporality.CUMULATIVE,
+                0,
+                record_min_max=False,
             )
         )
 
@@ -347,7 +356,10 @@ class TestExplicitBucketHistogramAggregation(TestCase):
 
         explicit_bucket_histogram_aggregation = (
             _ExplicitBucketHistogramAggregation(
-                Mock(), 0, boundaries=[0, 1, 2]
+                Mock(),
+                AggregationTemporality.DELTA,
+                0,
+                boundaries=[0, 1, 2],
             )
         )
 
@@ -367,6 +379,7 @@ class TestExplicitBucketHistogramAggregation(TestCase):
         explicit_bucket_histogram_aggregation.aggregate(measurement(1))
         # 2 is used here directly to simulate the instant the second
         # collection process starts.
+
         second_histogram = explicit_bucket_histogram_aggregation.collect(
             AggregationTemporality.CUMULATIVE, 2
         )
@@ -380,7 +393,9 @@ class TestExplicitBucketHistogramAggregation(TestCase):
 
     def test_boundaries(self):
         self.assertEqual(
-            _ExplicitBucketHistogramAggregation(Mock(), 0)._boundaries,
+            _ExplicitBucketHistogramAggregation(
+                Mock(), AggregationTemporality.CUMULATIVE, 0
+            )._boundaries,
             (
                 0.0,
                 5.0,
@@ -409,7 +424,8 @@ class TestAggregationFactory(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertTrue(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality, AggregationTemporality.DELTA
+            aggregation._instrument_aggregation_temporality,
+            AggregationTemporality.DELTA,
         )
         aggregation2 = factory._create_aggregation(counter, Mock(), 0)
         self.assertNotEqual(aggregation, aggregation2)
@@ -420,7 +436,8 @@ class TestAggregationFactory(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertFalse(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality, AggregationTemporality.DELTA
+            aggregation._instrument_aggregation_temporality,
+            AggregationTemporality.DELTA,
         )
 
         counter = _ObservableCounter("name", Mock(), Mock(), None)
@@ -429,7 +446,7 @@ class TestAggregationFactory(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertTrue(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality,
+            aggregation._instrument_aggregation_temporality,
             AggregationTemporality.CUMULATIVE,
         )
 
@@ -471,7 +488,8 @@ class TestDefaultAggregation(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertTrue(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality, AggregationTemporality.DELTA
+            aggregation._instrument_aggregation_temporality,
+            AggregationTemporality.DELTA,
         )
 
     def test_up_down_counter(self):
@@ -482,7 +500,8 @@ class TestDefaultAggregation(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertFalse(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality, AggregationTemporality.DELTA
+            aggregation._instrument_aggregation_temporality,
+            AggregationTemporality.DELTA,
         )
 
     def test_observable_counter(self):
@@ -495,7 +514,7 @@ class TestDefaultAggregation(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertTrue(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality,
+            aggregation._instrument_aggregation_temporality,
             AggregationTemporality.CUMULATIVE,
         )
 
@@ -511,7 +530,7 @@ class TestDefaultAggregation(TestCase):
         self.assertIsInstance(aggregation, _SumAggregation)
         self.assertFalse(aggregation._instrument_is_monotonic)
         self.assertEqual(
-            aggregation._instrument_temporality,
+            aggregation._instrument_aggregation_temporality,
             AggregationTemporality.CUMULATIVE,
         )
 
@@ -528,6 +547,19 @@ class TestDefaultAggregation(TestCase):
         )
         self.assertIsInstance(aggregation, _ExplicitBucketHistogramAggregation)
 
+    def test_gauge(self):
+
+        aggregation = self.default_aggregation._create_aggregation(
+            _Gauge(
+                "name",
+                Mock(),
+                Mock(),
+            ),
+            Mock(),
+            0,
+        )
+        self.assertIsInstance(aggregation, _LastValueAggregation)
+
     def test_observable_gauge(self):
 
         aggregation = self.default_aggregation._create_aggregation(
