@@ -33,7 +33,9 @@ from opentelemetry.sdk.environment_variables import (
     OTEL_BSP_MAX_QUEUE_SIZE,
     OTEL_BSP_SCHEDULE_DELAY,
 )
+from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk.trace import export
+from opentelemetry.sdk.trace.export import logger
 from opentelemetry.sdk.trace.export.in_memory_span_exporter import (
     InMemorySpanExporter,
 )
@@ -150,7 +152,7 @@ class TestSimpleSpanProcessor(unittest.TestCase):
         self.assertListEqual([], spans_names_list)
 
 
-def _create_start_and_end_span(name, span_processor):
+def _create_start_and_end_span(name, span_processor, resource):
     span = trace._Span(
         name,
         trace_api.SpanContext(
@@ -160,6 +162,7 @@ def _create_start_and_end_span(name, span_processor):
             trace_flags=trace_api.TraceFlags(trace_api.TraceFlags.SAMPLED),
         ),
         span_processor=span_processor,
+        resource=resource,
     )
     span.start()
     span.end()
@@ -175,7 +178,7 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
             OTEL_BSP_EXPORT_TIMEOUT: "4",
         },
     )
-    def test_batch_span_processor_environment_variables(self):
+    def test_args_env_var(self):
 
         batch_span_processor = export.BatchSpanProcessor(
             MySpanExporter(destination=[])
@@ -186,6 +189,39 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         self.assertEqual(batch_span_processor.max_export_batch_size, 3)
         self.assertEqual(batch_span_processor.export_timeout_millis, 4)
 
+    def test_args_env_var_defaults(self):
+
+        batch_span_processor = export.BatchSpanProcessor(
+            MySpanExporter(destination=[])
+        )
+
+        self.assertEqual(batch_span_processor.max_queue_size, 2048)
+        self.assertEqual(batch_span_processor.schedule_delay_millis, 5000)
+        self.assertEqual(batch_span_processor.max_export_batch_size, 512)
+        self.assertEqual(batch_span_processor.export_timeout_millis, 30000)
+
+    @mock.patch.dict(
+        "os.environ",
+        {
+            OTEL_BSP_MAX_QUEUE_SIZE: "a",
+            OTEL_BSP_SCHEDULE_DELAY: " ",
+            OTEL_BSP_MAX_EXPORT_BATCH_SIZE: "One",
+            OTEL_BSP_EXPORT_TIMEOUT: "@",
+        },
+    )
+    def test_args_env_var_value_error(self):
+
+        logger.disabled = True
+        batch_span_processor = export.BatchSpanProcessor(
+            MySpanExporter(destination=[])
+        )
+        logger.disabled = False
+
+        self.assertEqual(batch_span_processor.max_queue_size, 2048)
+        self.assertEqual(batch_span_processor.schedule_delay_millis, 5000)
+        self.assertEqual(batch_span_processor.max_export_batch_size, 512)
+        self.assertEqual(batch_span_processor.export_timeout_millis, 30000)
+
     def test_on_start_accepts_parent_context(self):
         # pylint: disable=no-self-use
         my_exporter = MySpanExporter(destination=[])
@@ -211,8 +247,9 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
 
         span_names = ["xxx", "bar", "foo"]
 
+        resource = Resource.create({})
         for name in span_names:
-            _create_start_and_end_span(name, span_processor)
+            _create_start_and_end_span(name, span_processor, resource)
 
         span_processor.shutdown()
         self.assertTrue(my_exporter.is_shutdown)
@@ -230,15 +267,16 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         span_names0 = ["xxx", "bar", "foo"]
         span_names1 = ["yyy", "baz", "fox"]
 
+        resource = Resource.create({})
         for name in span_names0:
-            _create_start_and_end_span(name, span_processor)
+            _create_start_and_end_span(name, span_processor, resource)
 
         self.assertTrue(span_processor.force_flush())
         self.assertListEqual(span_names0, spans_names_list)
 
         # create some more spans to check that span processor still works
         for name in span_names1:
-            _create_start_and_end_span(name, span_processor)
+            _create_start_and_end_span(name, span_processor, resource)
 
         self.assertTrue(span_processor.force_flush())
         self.assertListEqual(span_names0 + span_names1, spans_names_list)
@@ -264,10 +302,12 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
             my_exporter, max_queue_size=512, max_export_batch_size=128
         )
 
+        resource = Resource.create({})
+
         def create_spans_and_flush(tno: int):
             for span_idx in range(num_spans):
                 _create_start_and_end_span(
-                    f"Span {tno}-{span_idx}", span_processor
+                    f"Span {tno}-{span_idx}", span_processor, resource
                 )
             self.assertTrue(span_processor.force_flush())
 
@@ -289,7 +329,8 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         )
         span_processor = export.BatchSpanProcessor(my_exporter)
 
-        _create_start_and_end_span("foo", span_processor)
+        resource = Resource.create({})
+        _create_start_and_end_span("foo", span_processor, resource)
 
         # check that the timeout is not meet
         with self.assertLogs(level=WARNING):
@@ -307,8 +348,9 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
             my_exporter, max_queue_size=512, max_export_batch_size=128
         )
 
+        resource = Resource.create({})
         for _ in range(512):
-            _create_start_and_end_span("foo", span_processor)
+            _create_start_and_end_span("foo", span_processor, resource)
 
         time.sleep(1)
         self.assertTrue(span_processor.force_flush())
@@ -329,9 +371,10 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
             schedule_delay_millis=100,
         )
 
+        resource = Resource.create({})
         for _ in range(4):
             for _ in range(256):
-                _create_start_and_end_span("foo", span_processor)
+                _create_start_and_end_span("foo", span_processor, resource)
 
             time.sleep(0.1)  # give some time for the exporter to upload spans
 
@@ -433,7 +476,8 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         )
 
         # create single span
-        _create_start_and_end_span("foo", span_processor)
+        resource = Resource.create({})
+        _create_start_and_end_span("foo", span_processor, resource)
 
         self.assertTrue(export_event.wait(2))
         export_time = time.time()
@@ -463,7 +507,8 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         )
 
         with mock.patch.object(span_processor.condition, "wait") as mock_wait:
-            _create_start_and_end_span("foo", span_processor)
+            resource = Resource.create({})
+            _create_start_and_end_span("foo", span_processor, resource)
             self.assertTrue(export_event.wait(2))
 
             # give some time for exporter to loop
